@@ -4,6 +4,9 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Error" : "Fallu",
     "New note" : "Nota nueva",
+    "Help" : "Help",
+    "Result" : "Resultáu",
+    "Action" : "Aición",
     "No notes yet" : "Entá nun hai notes",
     "All notes" : "Toles notes",
     "Categories" : "Estayes",
@@ -13,15 +16,14 @@ OC.L10N.register(
     "This week" : "Esta selmana",
     "This month" : "Esti mes",
     "Rename" : "Renomar",
+    "Details" : "Detalles",
     "Delete note" : "Desaniciar nota",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "Detalles",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
     "Category" : "Estaya",
     "_%n word_::_%n words_" : ["%n pallabra","%n pallabres"],
-    "Android app" : "Aplicación p'Android",
-    "iOS app" : "Aplicación pa iOS"
+    "Tasks" : "Xeres"
 },
 "nplurals=2; plural=(n != 1);");
