@@ -4,15 +4,15 @@ OC.L10N.register(
     "Notes" : "Qeydlər",
     "Error" : "Səhv",
     "New note" : "Yeni qeyd",
+    "Help" : "Kömək",
     "Today" : "Bu gün",
     "Yesterday" : "Dünən",
     "Rename" : "Adı dəyiş",
+    "Details" : "Detallar",
     "Delete note" : "Qeydi sil",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "Detallar",
     "Edit" : "Dəyişiklik et",
-    "Android app" : "Android proqramı",
-    "iOS app" : "iOS proqramı"
+    "Tasks" : "Tapşırıqlar"
 },
 "nplurals=2; plural=(n != 1);");
