@@ -4,12 +4,16 @@ OC.L10N.register(
     "Notes" : "Noter",
     "Error" : "Fejl",
     "New note" : "Ny note",
+    "Help" : "Hjælp",
+    "Undo Delete" : "Annullér Slet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
+    "Result" : "Resultat",
+    "Action" : "Handling",
+    "Insert image" : "Indsæt billede",
     "Display mode for notes" : "Visningstilstand for noter",
     "Open in edit mode" : "Åbn i redigeringstilstand",
     "Open in preview mode" : "Åbn forhåndsvisning",
     "No notes yet" : "Ingen noter endnu",
-    "Insert image" : "Indsæt billede",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
     "Loading …" : "Indlæser…",
@@ -20,18 +24,18 @@ OC.L10N.register(
     "This month" : "Denne måned",
     "Last month" : "Seneste måned",
     "Rename" : "Omdøb",
+    "Note's title" : "Notens titel",
+    "Details" : "Detaljer",
     "Delete note" : "Slet note",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
     "Use current version" : "Brug aktuelle version",
-    "Details" : "Detaljer",
     "Edit" : "Redigér",
     "Preview" : "Vis eksempel",
     "Category" : "Katergori",
     "Uncategorized" : "Udenfor kategori",
     "Saving failed!" : "Kunne ikke gemme!",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
-    "Android app" : "Android app",
-    "iOS app" : "iOS app"
+    "Tasks" : "Opgaver"
 },
 "nplurals=2; plural=(n != 1);");
