@@ -4,6 +4,9 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nueva nota",
+    "Help" : "Ayuda",
+    "Result" : "Resultado",
+    "Action" : "Acción",
     "Display mode for notes" : "Modo de visualización para notas",
     "Open in edit mode" : "Abrir en modo editor",
     "Open in preview mode" : "Abrir en modo de vista previa",
@@ -18,16 +21,15 @@ OC.L10N.register(
     "This month" : "Este mes",
     "Last month" : "Mes pasado",
     "Rename" : "Renombrar",
+    "Details" : "Detalles",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
-    "Details" : "Detalles",
     "Edit" : "Editar",
     "Preview" : "Vista previa",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
-    "Android app" : "Aplicación android",
-    "iOS app" : "Aplicación iOS"
+    "Tasks" : "Tareas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
