@@ -1,11 +1,16 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nota nueva",
-    "Notes" : "Notas",
+    "Help" : "Ayuda",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Settings" : "Configuraciones ",
+    "Result" : "Resultado",
+    "Action" : "Acción",
+    "Open in edit mode" : "Abrir en modo edición",
+    "Open in preview mode" : "Abrir en modo previsualización",
+    "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "Today" : "Hoy",
@@ -13,17 +18,16 @@ OC.L10N.register(
     "This week" : "Esta semana",
     "This month" : "Este mes",
     "Rename" : "Renombrar",
+    "Details" : "Detalles",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Details" : "Detalles",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
-    "Android app" : "Aplicación Android",
-    "iOS app" : "Aplicación iOS"
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
+    "Tasks" : "Tareas"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
