@@ -5,11 +5,14 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nota nueva",
     "Distraction-free notes and writing" : "Notas y escritura libre de distracciones",
+    "Help" : "Ayuda",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "Result" : "Resultado",
+    "Action" : "Acción",
+    "Insert image" : "Añadir imagen",
     "Open in edit mode" : "Abrir en modo edición",
     "Open in preview mode" : "Abrir en modo previsualización",
     "No notes yet" : "Aún no hay notas",
-    "Insert image" : "Añadir imagen",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "Today" : "Hoy",
@@ -17,18 +20,17 @@ OC.L10N.register(
     "This week" : "Esta semana",
     "This month" : "Este mes",
     "Rename" : "Renombrar",
+    "Details" : "Detalles",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Use current version" : "Usar la versión actual",
-    "Details" : "Detalles",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
     "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
-    "Android app" : "Aplicación Android",
-    "iOS app" : "Aplicación iOS"
+    "Tasks" : "Tareas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
