@@ -4,21 +4,21 @@ OC.L10N.register(
     "Notes" : "Märkmed",
     "Error" : "Viga",
     "New note" : "Uus märge",
-    "Settings" : "Seaded",
+    "Help" : "Abiinfo",
     "No notes yet" : "Märkmeid veel pole",
     "Categories" : "Kategooriad",
     "Today" : "Täna",
     "Yesterday" : "Eile",
     "Rename" : "Nimeta ümber",
+    "Details" : "Üksikasjad",
     "Delete note" : "Kustuta märge",
     "Remove from favorites" : "Eemalda lemmikutest",
     "Add to favorites" : "Lisa lemmikutesse",
-    "Details" : "Üksikasjad",
+    "Use current version" : "Kasuta praegust versiooni",
     "Edit" : "Redigeeri",
     "Preview" : "Eelvaade",
     "Category" : "Kategooria",
     "_%n word_::_%n words_" : ["%n sõna","%n sõna"],
-    "Android app" : "Androidi rakendus",
-    "iOS app" : "iOS-i rakendus"
+    "Tasks" : "Ülesanded"
 },
 "nplurals=2; plural=(n != 1);");
