@@ -6,14 +6,62 @@ OC.L10N.register(
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
     "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
+    "Help" : "Ohje",
     "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
     "Deleted {title}" : "Poistettu {title}",
-    "Undo Delete" : "Kumoa poistaminen",
+    "Undo Delete" : "Kumoa",
     "Note recovered" : "Muistiinpano palautettu",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Palautettu {number} muistiinpano","Palautettu {number} muistiinpanoa"],
-    "Notes settings" : "Muistiinpanojen asetukset",
+    "Basics" : "Perusteet",
+    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
+    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
+    "Markdown" : "Markdown",
+    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
+    "Sequence" : "Merkkijono",
+    "Result" : "Tulos",
+    "Visualized" : "Visalisoitu",
+    "Shortcuts" : "Pikanäppäimet",
+    "Use shortcuts to quickly navigate this app." : "Käytä pikanäppäimiä nopeaan siirtymiseen sovelluksessa.",
+    "Shortcut" : "Pikanäppäin",
+    "Action" : "Toiminto",
+    "Mobile apps" : "Mobiilisovellukset",
+    "CTRL" : "CTRL",
+    "Make the selection bold" : "Lihavoi valinta",
+    "Make the selection italic" : "Kursivoi valinta",
+    "Wrap the selection in quotes" : "Aseta valinta lainausmerkkeihin",
+    "ALT" : "ALT",
+    "The selection will be turned into monospace" : "Valinta muutetaan monospaceksi",
+    "Remove any styles from the selected text" : "Poista kaikki tyylit valitusta tekstistä",
+    "Makes the current line a list element" : "Tee nykyisestä rivistä listaelementti",
+    "Makes the current line a list element with a number" : "Tee nykyisestä rivistä numeroitu listaelementti",
+    "Toggle heading for current line" : "Vaihda rivin otsikkoasetusta",
+    "SHIFT" : "SHIFT",
+    "Set the current line as a big heading" : "Tee nykyisestä rivistä suuri otsikko",
+    "Insert link" : "Lisää linkki",
+    "Insert image" : "Lisää kuva",
+    "Switch between editor and viewer" : "Vaihda muokkaus- ja katselutilan välllä",
+    "bold" : "lihavoitu",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
+    "italic" : "kursivoitu",
+    "strikethrough" : "yliviivattu",
+    "Big header" : "Suuri otsikko",
+    "Medium header" : "Keskikokoinen otsikko",
+    "Small header" : "Pienehkö otsikko",
+    "Tiny header" : "Pieni otsikko",
+    "Generic list item" : "Yleinen listaelementti",
+    "Generic list" : "Yleinen lista",
+    "Numbered list" : "Numeroitu lista",
+    "Link title" : "Linkin otsikko",
+    "link" : "linkki",
+    "Image title" : "Kuvan otsikko",
+    "image" : "kuva",
+    "This is a quote." : "Tämä on lainaus.",
+    "quote" : "lainaus",
+    "code" : "koodi",
+    "Multi line block code" : "Monirivinen koodialue",
+    "Notes settings" : "Asetukset",
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
     "Root directory" : "Juurihakemisto",
     "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
@@ -21,13 +69,16 @@ OC.L10N.register(
     "User defined" : "Käyttäjän määrittelemä",
     "Open in edit mode" : "Avaa muokkaustilassa",
     "Open in preview mode" : "Avaa esikatselutilassa",
+    "Create a sample note with markdown" : "Luo muistiinpanoesimerkki markdownilla",
     "No notes yet" : "Ei muistiinpanoja",
     "Upload image" : "Lataa kuva",
-    "Insert image" : "Lisää kuva",
     "Select an image" : "Valitse kuva",
     "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Et voi valita kuvia muistiinpanohakemiston ulkopuolelta. Muistiinpanojesi hakemisto: {folder}",
     "Wrong image" : "Väärä kuva",
     "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Asenna sovellus puhelimeesi käyttääksesi muistiinpanoja missä tahansa.",
+    "Android app: {notes} by {company}" : "Android-sovellus: {notes} by {company}",
+    "iOS app: {notes} by {company}" : "iOS-sovellus: {notes} by {company}",
     "All notes" : "Kaikki muistiinpanot",
     "Categories" : "Luokat",
     "Loading …" : "Ladataan…",
@@ -39,6 +90,7 @@ OC.L10N.register(
     "Last month" : "Viime kuussa",
     "Rename" : "Nimeä uudelleen",
     "Note's title" : "Muistiinpanon otsikko",
+    "Details" : "Tiedot",
     "Delete note" : "Poista muistiinpano",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
@@ -48,7 +100,6 @@ OC.L10N.register(
     "Use current version" : "Käytä nykyistä versiota",
     "Empty note" : "Tyhjä muistiinpano",
     "Write …" : "Kirjoita…",
-    "Details" : "Tiedot",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Muokkaa",
     "Preview" : "Esikatselu",
@@ -58,9 +109,9 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
     "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
     "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
-    "Set category" : "Aseta luokka",
     "Category" : "Luokka",
     "Uncategorized" : "Luokittelematon",
+    "Set category" : "Aseta luokka",
     "Click here to save manually" : "Napsauta tästä tallentaaksesi manuaalisesti",
     "Saving failed!" : "Tallentaminen epäonnistui!",
     "Last modified: {date}" : "Viimeksi muokattu: {date}",
@@ -68,13 +119,6 @@ OC.L10N.register(
     "Subcategory" : "Aliluokka",
     "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
     "_%n character_::_%n characters_" : ["%n merkki","%n merkkiä "],
-    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
-    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
-    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Asenna sovellus puhelimeesi käyttääksesi muistiinpanoja missä tahansa.",
-    "Android app" : "Android-sovellus",
-    "iOS app" : "iOS-sovellus",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Voit luoda alikategorioita käyttämällä /-merkkiä eroittimena yläkategorian ja alikategorian välissä esim: \"{parent}/{sub}\".",
     "Note not found." : "Muistiinpanoa ei löytynyt.",
     "Note is locked." : "Muistiinpano on lukittu.",
@@ -91,8 +135,26 @@ OC.L10N.register(
     "Updating title for note {id} has failed." : "Muistiinpanon {id} otsikon vaihtaminen on epäonnistunut.",
     "Undo delete has failed for note {title}." : "Poistamisen kumoaminen epäonnistui muistiinpanolle {title}.",
     "Deleting note {id} has failed." : "Muistiinpanon {id} poistaminen epäonnistui.",
+    "Toggling favorite for note {id} has failed." : "Suosikkiasetuksen muuttaminen muistiinpanolle {id} epäonnistui.",
     "Updating the note's category has failed. Is the target directory writable?" : "Muistiinpanon kategorian vaihtaminen epäonnistui. Onko kohdehakemistoon kirjoitusoikeuksia?",
     "Updating the category for note {id} has failed." : "Muistiinpanon {id} kategorian vaihtaminen on epäonnistunut.",
-    "Development Mode" : "Kehitystila"
+    "Sample note" : "Esimerkkimuistiinpano",
+    "15 January 2021, via Nextcloud Notes" : "15. Tammikuuta 2021, Nextcloud Muistiinpanot",
+    "Me, you, and all our friends!" : "Minä, sinä ja kaikki ystävämme!",
+    "Tasks" : "Tehtävät",
+    "Write nice todo lists" : "Kirjoita kivoja todo-listoja",
+    "Buy Fries" : "Osta ranskalaisia perunoita",
+    "Birthdays" : "Syntymäpäivät",
+    "Jen, in three days!" : "Jenni, kolmen päivän päästä!",
+    "Moss, 21.03.1973" : "Matti, 21.03.1973",
+    "Roy, 1979" : "Roni, 1979",
+    "Review Steps" : "Tarkistuksen vaiheet",
+    "Turn PC off" : "Sammuta tietokone",
+    "Turn PC on" : "Käynnistä tietokone",
+    "Then call IT" : "Soita sitten IT-tukeen",
+    "Quotes" : "Lainaukset",
+    "Nextcloud, a safe home for all your data" : "Nextcloud on turvallinen koti kaikille tiedoillesi",
+    "Development Mode" : "Kehitystila",
+    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Näyttää siltä, että muistiinpanosovellus on asennettu sovelluskehittäjien lähteestä. Asenna se virallisesta <a href=\"%1$s\">Nextcloud App Storesta</a> . Jos haluat rakentaa sovelluksen itse lähdekoodista, lue  <a href=\"%2$s\">sovelluskehittäjän ohjeet</a>."
 },
 "nplurals=2; plural=(n != 1);");
