@@ -4,21 +4,20 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nove nota",
+    "Help" : "Adjuta",
     "No notes yet" : "Nulle notas ancora",
     "Today" : "Hodie",
     "Yesterday" : "Heri",
     "This week" : "Iste septimana",
     "This month" : "Iste mense",
     "Rename" : "Renominar",
+    "Details" : "Detalios",
     "Delete note" : "Dele nota",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "Detalios",
     "Edit" : "Modificar",
     "Preview" : "Previsualisar",
     "Category" : "Categoria",
-    "_%n word_::_%n words_" : ["%n parola","%n parolas"],
-    "Android app" : "Application Android",
-    "iOS app" : "Application iOS"
+    "_%n word_::_%n words_" : ["%n parola","%n parolas"]
 },
 "nplurals=2; plural=(n != 1);");
