@@ -4,6 +4,7 @@ OC.L10N.register(
     "Notes" : "Catatan",
     "Error" : "Kesalahan",
     "New note" : "Catatan baru",
+    "Help" : "Bantuan",
     "No notes yet" : "Belum ada catatan",
     "All notes" : "Semua catatan",
     "Categories" : "Kategori",
@@ -12,15 +13,15 @@ OC.L10N.register(
     "This week" : "Pekan ini",
     "This month" : "Bulan ini",
     "Rename" : "Ubah nama",
+    "Details" : "Detil",
     "Delete note" : "Hapus catatan",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
-    "Details" : "Detil",
     "Edit" : "Sunting",
     "Preview" : "Pratinjau",
     "Category" : "Kategori",
     "_%n word_::_%n words_" : ["%n kata"],
-    "Android app" : "Aplikasi Android",
-    "iOS app" : "Aplikasi iOS"
+    "Tasks" : "Tugas",
+    "Nextcloud, a safe home for all your data" : "Nextcloud, rumah yang aman untuk semua data Anda"
 },
 "nplurals=1; plural=0;");
