@@ -5,14 +5,17 @@ OC.L10N.register(
     "Error" : "Villa",
     "New note" : "Nýr minnispunktur",
     "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
+    "Help" : "Hjálp",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
+    "Result" : "Niðurstöður",
+    "Action" : "Aðgerð",
+    "Insert image" : "Setja inn mynd",
     "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
     "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
     "Display mode for notes" : "Birtingarhamur minnispunkta",
     "Open in edit mode" : "Opna í breytingaham",
     "Open in preview mode" : "Opna í forskoðunarham",
     "No notes yet" : "Engir minnispunktar ennþá",
-    "Insert image" : "Setja inn mynd",
     "All notes" : "Allir minnispunktar",
     "Categories" : "Flokkar",
     "Loading …" : "Hleð inn …",
@@ -21,11 +24,11 @@ OC.L10N.register(
     "This week" : "Í þessari viku",
     "This month" : "Í þessum mánuði",
     "Rename" : "Endurnefna",
+    "Details" : "Details",
     "Delete note" : "Eyða minnispunkti",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
     "Use current version" : "Nota fyrirliggjandi útgáfu",
-    "Details" : "Details",
     "Edit" : "Breyta",
     "Preview" : "Forskoðun",
     "Category" : "Flokkur",
@@ -33,8 +36,7 @@ OC.L10N.register(
     "Saving failed!" : "Vistun mistókst!",
     "Subcategory" : "Undirflokkur",
     "_%n word_::_%n words_" : ["%n orð","%n orð"],
-    "Android app" : "Android-forrit",
-    "iOS app" : "iOS-forrit",
-    "Updating the note's category has failed. Is the target directory writable?" : "Uppfærsla á flokki minnispunkts mistókst. Er móttökumappan skrifanleg?"
+    "Updating the note's category has failed. Is the target directory writable?" : "Uppfærsla á flokki minnispunkts mistókst. Er móttökumappan skrifanleg?",
+    "Tasks" : "Verkefni"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
