@@ -4,12 +4,14 @@ OC.L10N.register(
     "Notes" : "កំណត់​ចំណាំ",
     "Error" : "កំហុស",
     "New note" : "កំណត់​ចំណាំ​ថ្មី",
+    "Help" : "ជំនួយ",
     "Today" : "ថ្ងៃ​នេះ",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
+    "Details" : "ព័ត៌មាន​លម្អិត",
     "Delete note" : "លុប​កំណត់​ចំណាំ",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "ព័ត៌មាន​លម្អិត",
-    "Edit" : "កែប្រែ"
+    "Edit" : "កែប្រែ",
+    "Tasks" : "ភារកិច្ច"
 },
 "nplurals=1; plural=0;");
