@@ -4,6 +4,8 @@ OC.L10N.register(
     "Notes" : "Piezīmes",
     "Error" : "Kļūda",
     "New note" : "Jauna piezīme",
+    "Help" : "Palīdzība",
+    "Action" : "Darbība",
     "No notes yet" : "Nav nevienas piezīmes",
     "All notes" : "Visas piezīmes",
     "Categories" : "Kategorijas",
@@ -12,16 +14,16 @@ OC.L10N.register(
     "This week" : "Šonedēļ",
     "This month" : "Šis mēnesis",
     "Rename" : "Pārsaukt",
+    "Details" : "Detaļas",
     "Delete note" : "Dzēst piezīmi",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
-    "Details" : "Detaļas",
     "Edit" : "Rediģēt",
     "Preview" : "Priekšskatīt",
     "Category" : "Kategorija",
     "Uncategorized" : "Bez kategorijas",
     "_%n word_::_%n words_" : ["%n words","%n vārdi","%n vārdi"],
-    "Android app" : "Android lietotne",
-    "iOS app" : "iOS lietotne"
+    "Updating settings has failed." : "Iestatījumu atjaunināšana neizdevās.",
+    "Tasks" : "Uzdevumi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
