@@ -4,8 +4,15 @@ OC.L10N.register(
     "Notes" : "Notater",
     "Error" : "Feil",
     "New note" : "Nytt notat",
+    "Help" : "Hjelp",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finnes ulagrede notater. Å forlate siden vil forkaste alle endringer!",
-    "Settings" : "Innstillinger",
+    "Result" : "Resultat",
+    "Shortcuts" : "Snarveier",
+    "Action" : "Handling",
+    "Insert image" : "Sett inn bilde",
+    "Display mode for notes" : "Visningsmodus for notater",
+    "Open in edit mode" : "Åpne i redigeringsmodus",
+    "Open in preview mode" : "Åpne i forhåndsvisningsmodus",
     "No notes yet" : "Ingen notater enda",
     "All notes" : "Alle notater",
     "Categories" : "Kategorier",
@@ -17,17 +24,17 @@ OC.L10N.register(
     "This month" : "Denne måneden",
     "Last month" : "Forrige måned",
     "Rename" : "Endre navn",
+    "Details" : "Detaljer",
     "Delete note" : "Slett notat",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Legg til i favoritter",
-    "Details" : "Detaljer",
+    "Use current version" : "Bruk siste versjon",
     "Edit" : "Rediger",
     "Preview" : "Forhåndsvis",
     "Category" : "Kategori",
     "Uncategorized" : "Ukategorisert",
     "Saving failed!" : "Lagring mislyktes!",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
-    "Android app" : "Android-app",
-    "iOS app" : "iOS-app"
+    "Tasks" : "Oppgaver"
 },
 "nplurals=2; plural=(n != 1);");
