@@ -4,14 +4,16 @@ OC.L10N.register(
     "Notes" : "Notat",
     "Error" : "Feil",
     "New note" : "Nytt notat",
+    "Help" : "Hjelp",
     "Today" : "I dag",
     "Yesterday" : "i går",
     "Rename" : "Gje nytt namn",
+    "Details" : "Detaljar",
     "Delete note" : "Slett notat",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "Detaljar",
     "Edit" : "Endra",
-    "Category" : "Kategori"
+    "Category" : "Kategori",
+    "Tasks" : "Oppgåver"
 },
 "nplurals=2; plural=(n != 1);");
