@@ -6,6 +6,7 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nòta novèla",
     "Distraction-free notes and writing" : "Nòtas e escritura sens cap de distraccion",
+    "Help" : "Ajuda",
     "Please see Nextcloud server log for details." : "Consultatz los jornals d'audit del servidor Nextcloud per mai de detalhs.",
     "Deleted {title}" : "{title} suprimit",
     "Undo Delete" : "Anullar la supression",
@@ -13,11 +14,14 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "I a de nòtas pas enregistradas. Quitar la pagina farà pèrdre las modificacions !",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} nòta suprimida","{number} nòtas suprimidas"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} nòta restaurada","{number} nòtas restauradas"],
+    "Organize your notes in categories." : "Organizatz vòstras nòtas en categorias.",
+    "Insert image" : "Inserir imatge",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Començatz d’escriure una nòta en clicant « {newnode} » dins la barra de navegacion.",
     "Folder to store your notes" : "Dossièr ont gardar vòstras nòtas",
     "File extension for new notes" : "Extension fichièr per las nòtas novèlas",
     "Display mode for notes" : "Mòde d’afichatge per las nòtas",
     "No notes yet" : "Cap de nòta pel moment",
-    "Insert image" : "Inserir imatge",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installatz l’aplicacion per mobil per accedir a vòstras nòtas de pertot.",
     "All notes" : "Totas las nòtas",
     "Categories" : "Categorias",
     "Loading …" : "Cargament…",
@@ -29,6 +33,7 @@ OC.L10N.register(
     "Last month" : "Lo mes passat",
     "Rename" : "Renomenar",
     "Note's title" : "Títol de la nòta",
+    "Details" : "Detalhs",
     "Delete note" : "Suprimir la nòta",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -37,15 +42,14 @@ OC.L10N.register(
     "Use current version" : "Utilizar la version actuala",
     "Empty note" : "Nòta voida",
     "Write …" : "Escrivètz…",
-    "Details" : "Detalhs",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Modificar",
     "Preview" : "Apercebut",
     "Exit full screen" : "Sortir de l’ecran complèt",
     "Full screen" : "Ecran complèt",
-    "Set category" : "Definir categoria",
     "Category" : "Categoria",
     "Uncategorized" : "Sens categoria",
+    "Set category" : "Definir categoria",
     "Click here to save manually" : "Clicatz aquí per enregistrar manualament",
     "Saving failed!" : "Fracàs de l'enregistrament !",
     "Last modified: {date}" : "Darrièra modificacion : {date}",
@@ -53,14 +57,10 @@ OC.L10N.register(
     "Subcategory" : "Soscategoria",
     "_%n word_::_%n words_" : ["%n mot","%n mots"],
     "_%n character_::_%n characters_" : ["%n caractèr","%n caractèrs"],
-    "Organize your notes in categories." : "Organizatz vòstras nòtas en categorias.",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installatz l’aplicacion per mobil per accedir a vòstras nòtas de pertot.",
-    "Android app" : "Aplicacion Android",
-    "iOS app" : "Aplicacion iOS",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Començatz d’escriure una nòta en clicant « {newnode} » dins la barra de navegacion.",
     "Note not found." : "Cap de nòta pas trobada.",
     "Note is locked." : "La nòta es verrolhada.",
     "Insufficient storage." : "Espaci d'emmagazinatge insufisent.",
+    "Tasks" : "Prètzfaches",
     "Development Mode" : "Mòde desvelopament"
 },
 "nplurals=2; plural=(n > 1);");
