@@ -3,11 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "شسیب",
     "Error" : "شسیب",
+    "Help" : "مرسته",
     "Today" : "نن",
     "Yesterday" : "پرون",
     "Rename" : "نوم بدلول",
+    "Details" : "معلومات",
     "Remove from favorites" : "له نښو ويستل",
-    "Add to favorites" : "په نښه کول",
-    "Details" : "معلومات"
+    "Add to favorites" : "په نښه کول"
 },
 "nplurals=2; plural=(n != 1);");
