@@ -4,24 +4,29 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Erro",
     "New note" : "Nova nota",
-    "Settings" : "Definições",
+    "Help" : "Ajuda",
+    "Open in edit mode" : "Abrir no modo de edição",
+    "Open in preview mode" : "Abrir no modo de visualização",
     "No notes yet" : "Sem notas ainda",
     "All notes" : "Todas as notas",
     "Categories" : "Categorias",
+    "Loading …" : "A carregar...",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "This week" : "Esta semana",
+    "Last week" : "Ultima semana",
     "This month" : "Este mês",
+    "Last month" : "Ultimo mês",
     "Rename" : "Renomear",
+    "Details" : "Detalhes",
     "Delete note" : "Apagar nota",
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
-    "Details" : "Detalhes",
+    "Use current version" : "Usar esta versão",
     "Edit" : "Editar",
     "Preview" : "Pré-visualização",
     "Category" : "Categoria",
-    "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
-    "Android app" : "Aplicação Android",
-    "iOS app" : "Aplicação iOS"
+    "_%n word_::_%n words_" : ["%n palavra","%n palavras","%n palavras"],
+    "Tasks" : "Tarefas"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
