@@ -4,6 +4,7 @@ OC.L10N.register(
     "Notes" : "සටහන්",
     "Error" : "දෝෂය",
     "New note" : "නව සටහන",
+    "Help" : "උපකාර",
     "No notes yet" : "තවම සටහන් නැත",
     "All notes" : "සියලුම සටහන්",
     "Loading …" : "පූරණය වෙමින් …",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Details" : "විස්තර",
     "Edit" : "සංස්කරණය",
     "Preview" : "පෙරදසුන",
-    "Category" : "ප්‍රවර්ගය"
+    "Category" : "ප්‍රවර්ගය",
+    "Tasks" : "කාර්යයන්"
 },
 "nplurals=2; plural=(n != 1);");
