@@ -6,6 +6,7 @@ OC.L10N.register(
     "Error" : "Fel",
     "New note" : "Ny anteckning",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
+    "Help" : "Hjälp",
     "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
     "Deleted {title}" : "Raderad {title}",
     "Undo Delete" : "Ångra radering",
@@ -13,13 +14,21 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
+    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
+    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
+    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
+    "Result" : "Resultat",
+    "Shortcuts" : "Genvägar",
+    "Action" : "Action",
+    "Insert image" : "Infoga bild",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
     "Display mode for notes" : "Visningsläge för anteckningar",
     "Open in edit mode" : "Öppna i redigeringsläge",
     "Open in preview mode" : "Öppna i granskningsläge",
     "No notes yet" : "Inga anteckningar än",
-    "Insert image" : "Infoga bild",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
     "All notes" : "Alla anteckningar",
     "Categories" : "Kategorier",
     "Loading …" : "Läser in ...",
@@ -31,6 +40,7 @@ OC.L10N.register(
     "Last month" : "Förra månaden",
     "Rename" : "Byt namn",
     "Note's title" : "Anteckningens titel",
+    "Details" : "Detaljer",
     "Delete note" : "Ta bort anteckning",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
@@ -40,7 +50,6 @@ OC.L10N.register(
     "Use current version" : "Använd nuvarande version",
     "Empty note" : "Tom anteckning",
     "Write …" : "Skriv ...",
-    "Details" : "Detaljer",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Redigera",
     "Preview" : "Förhandsvisa",
@@ -50,9 +59,9 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
     "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
     "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
-    "Set category" : "Ange kategori",
     "Category" : "Kategori",
     "Uncategorized" : "Okategoriserad",
+    "Set category" : "Ange kategori",
     "Click here to save manually" : "Klicka här för att spara manuellt.",
     "Saving failed!" : "Misslyckades att spara!",
     "Last modified: {date}" : "Senast ändrad: {date}",
@@ -60,13 +69,6 @@ OC.L10N.register(
     "Subcategory" : "Underkategori",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
     "_%n character_::_%n characters_" : ["%n tecken","%n tecken"],
-    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
-    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
-    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
-    "Android app" : "Android-app",
-    "iOS app" : "iOS-app",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
     "Note not found." : "Anteckningen hittades inte.",
     "Note is locked." : "Anteckningen är låst.",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
     "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
     "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
+    "Tasks" : "Uppgifter",
     "Development Mode" : "Utvecklingsläge",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
 },
