@@ -3,12 +3,14 @@ OC.L10N.register(
     {
     "Notes" : "குறிப்புகள்",
     "Error" : "வழு",
+    "Help" : "உதவி",
     "Today" : "இன்று",
     "Yesterday" : "நேற்று",
     "Rename" : "பெயர்மாற்றம்",
+    "Details" : "விவரங்கள்",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Details" : "விவரங்கள்",
-    "Edit" : "தொகுக்க"
+    "Edit" : "தொகுக்க",
+    "Tasks" : "கடமைகள்"
 },
 "nplurals=2; plural=(n != 1);");
