@@ -1,30 +1,31 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "บันทึกย่อ",
+    "Notes" : "โน้ต",
     "Error" : "ข้อผิดพลาด",
-    "New note" : "สร้างบันทึกใหม่",
+    "New note" : "โน้ตใหม่",
+    "Help" : "ช่วยเหลือ",
     "Display mode for notes" : "โหมดแสดงผลสำหรับโน้ต",
     "Open in edit mode" : "เปิดในโหมดแก้ไข",
     "Open in preview mode" : "เปิดในโหมดแสดงตัวอย่าง",
     "All notes" : "โน้ตทั้งหมด",
+    "Loading …" : "กำลังโหลด …",
     "Today" : "วันนี้",
-    "Yesterday" : "เมื่อวานนี้",
+    "Yesterday" : "เมื่อวาน",
     "This week" : "สัปดาห์นี้",
     "Last week" : "สัปดาห์ที่แล้ว",
     "This month" : "เดือนนี้",
     "Last month" : "เดือนที่แล้ว",
     "Rename" : "เปลี่ยนชื่อ",
-    "Delete note" : "ลบบันทึกย่อ",
-    "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites",
     "Details" : "รายละเอียด",
+    "Delete note" : "ลบโน้ต",
+    "Remove from favorites" : "เอาออกจากรายการโปรด",
+    "Add to favorites" : "เพิ่มในรายการโปรด",
     "Edit" : "แก้ไข",
     "Preview" : "ตัวอย่าง",
     "Category" : "หมวดหมู่",
     "Uncategorized" : "ไม่ได้จัดหมวดหมู่",
     "_%n word_::_%n words_" : ["%n คำ"],
-    "Android app" : "แอพฯ แอนดรอยด์",
-    "iOS app" : "แอพฯ IOS"
+    "Tasks" : "งาน"
 },
 "nplurals=1; plural=0;");
