@@ -3,10 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "ئىزاھاتلار",
     "Error" : "خاتالىق",
+    "Help" : "ياردەم",
     "Today" : "بۈگۈن",
     "Rename" : "ئات ئۆزگەرت",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Edit" : "تەھرىر"
+    "Edit" : "تەھرىر",
+    "Tasks" : "ۋەزىپەلەر"
 },
 "nplurals=2; plural=(n != 1);");
